summaryrefslogtreecommitdiff
path: root/resources/jquery.ui/jquery.ui.droppable.js
diff options
context:
space:
mode:
Diffstat (limited to 'resources/jquery.ui/jquery.ui.droppable.js')
-rw-r--r--resources/jquery.ui/jquery.ui.droppable.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/resources/jquery.ui/jquery.ui.droppable.js b/resources/jquery.ui/jquery.ui.droppable.js
index afce00aa..4b98b3ad 100644
--- a/resources/jquery.ui/jquery.ui.droppable.js
+++ b/resources/jquery.ui/jquery.ui.droppable.js
@@ -1,7 +1,7 @@
/*
* jQuery UI Droppable 1.8.17
*
- * Copyright 2011, AUTHORS.txt (http://jqueryui.com/about)
+ * Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
* http://jquery.org/license
*
@@ -147,7 +147,7 @@ $.widget("ui.droppable", {
});
$.extend($.ui.droppable, {
- version: "1.8.17"
+ version: "1.8.23"
});
$.ui.intersect = function(draggable, droppable, toleranceMode) {
@@ -1,7 +1,7 @@
-/*
- * jQuery UI Droppable 1.8.17
+/*!
+ * jQuery UI Droppable 1.8.23
*